@@ -12,4 +12,4 @@
 # copyright notice, and modified files need to carry a notice indicating
 # that they have been altered from the originals.
 
-"""IBM Q Experience API connector and utilities."""
+"""IBM Quantum Experience API connector and utilities."""
