@@ -12,23 +12,23 @@
 # copyright notice, and modified files need to carry a notice indicating
 # that they have been altered from the originals.
 
-"""REST clients for accessing the IBM Q Experience API."""
+"""Base REST adapter."""
 
 from ..session import RetrySession
 
 
 class RestAdapterBase:
-    """Base class for REST adaptors."""
+    """Base class for REST adapters."""
 
     URL_MAP = {}  # type: ignore[var-annotated]
-    """Mapping between the internal name of an endpoint and the actual URL"""
+    """Mapping between the internal name of an endpoint and the actual URL."""
 
     def __init__(self, session: RetrySession, prefix_url: str = '') -> None:
         """RestAdapterBase constructor.
 
         Args:
-            session: session to be used in the adaptor.
-            prefix_url: string to be prefixed to all urls.
+            session: Session to be used in the adapter.
+            prefix_url: String to be prepend to all URLs.
         """
         self.session = session
         self.prefix_url = prefix_url
@@ -37,9 +37,9 @@ class RestAdapterBase:
         """Return the resolved URL for the specified identifier.
 
         Args:
-            identifier: internal identifier of the endpoint.
+            identifier: Internal identifier of the endpoint.
 
         Returns:
-            the resolved URL of the endpoint (relative to the session base url).
+            The resolved URL of the endpoint (relative to the session base URL).
         """
         return '{}{}'.format(self.prefix_url, self.URL_MAP[identifier])
